aboutsummaryrefslogtreecommitdiff
path: root/build2/cc/common.hxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2017-05-29 14:05:21 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2017-05-29 14:05:21 +0200
commitf69a53d0b83f6b6448aeacb98442b90e938696f3 (patch)
treeedfd544ed849eacbdc2d23f16aef6e27f34ad13c /build2/cc/common.hxx
parentd2d15fd4f70da8959d8222229c4e12c85ead8db3 (diff)
Add ability to limit amount of preprocessing done on source
The cc.preprocessed variable can be 'none' (not preprocessed), 'includes' (no depends on preprocessor, e.g., #ifdef, etc), and 'all' (the source is fully preprocessed). Note that for 'all' the source can still contain comments and line continuations.
Diffstat (limited to 'build2/cc/common.hxx')
-rw-r--r--build2/cc/common.hxx9
1 files changed, 5 insertions, 4 deletions
diff --git a/build2/cc/common.hxx b/build2/cc/common.hxx
index 135f5b1..55e6675 100644
--- a/build2/cc/common.hxx
+++ b/build2/cc/common.hxx
@@ -30,7 +30,7 @@ namespace build2
lang x_lang;
const char* x; // Module name ("c", "cxx").
- const char* x_name; // Compiler name ("c", "c++"; also used in -x).
+ const char* x_name; // Compiler name ("c", "c++").
const char* x_default; // Compiler default ("gcc", "g++").
const char* x_pext; // Preprocessed source extension (".i", ".ii").
@@ -64,9 +64,10 @@ namespace build2
const variable& c_export_loptions;
const variable& c_export_libs;
- const variable& c_type; // cc.type
- const variable& c_system; // cc.system
- const variable& c_reprocess; // cc.reprocess
+ const variable& c_type; // cc.type
+ const variable& c_system; // cc.system
+ const variable& c_reprocess; // cc.reprocess
+ const variable& c_preprocessed; // cc.preprocessed
const variable& x_std;